_`umbra.ui.widgets.notification_QLabel`
=======================================

.. automodule:: umbra.ui.widgets.notification_QLabel

Module Attributes
-----------------

.. attribute:: umbra.ui.widgets.notification_QLabel.LOGGER

Classes
-------

.. autoclass:: Notification_QLabel
	:show-inheritance:
	:members:

